@@ -34,7 +34,7 @@
 #endif
 
 #include <glib.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 
@@ -2200,7 +2200,7 @@ e_cal_backend_groupwise_store_settings (GwSettings *hold)
 
 	cbgw = hold->cbgw;
 	opts = hold->opts;
-	source = e_cal_backend_get_source (E_CAL_BACKEND (cbgw));
+	source = e_backend_get_source (E_BACKEND (cbgw));
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND (cbgw));
 
 	/* TODO implement send options for Notes */
