@@ -27,7 +27,7 @@
 #include "camel-gw-listener.h"
 #include "camel-groupwise-settings.h"
 #include <string.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <camel/camel.h>
 #include <e-gw-connection.h>
 #include <libedataserverui/e-passwords.h>
