@@ -17,10 +17,15 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <e-util/e-account-utils.h>
+#include <e-util/e-util.h>
 
 #include <shell/e-shell-view.h>
 #include <shell/e-shell-window.h>
@@ -166,9 +171,9 @@ gw_ui_mail_folder_popup (GtkUIManager *ui_manager,
 	shell_window = e_shell_view_get_shell_window (shell_view);
 	action_group = e_shell_window_get_action_group (shell_window, "mail");
 
-	gtk_action_group_add_actions (
-		action_group, mfp_entries,
-		G_N_ELEMENTS (mfp_entries), shell_view);
+	e_action_group_add_actions_localized (
+		action_group, GETTEXT_PACKAGE,
+		mfp_entries, G_N_ELEMENTS (mfp_entries), shell_view);
 
 	g_signal_connect (shell_view, "update-actions", G_CALLBACK (update_mfp_entries_cb), NULL);
 
@@ -260,9 +265,9 @@ gw_ui_mail_message_popup (GtkUIManager *ui_manager,
 	shell_window = e_shell_view_get_shell_window (shell_view);
 	action_group = e_shell_window_get_action_group (shell_window, "mail");
 
-	gtk_action_group_add_actions (
-		action_group, mmp_entries,
-		G_N_ELEMENTS (mmp_entries), shell_view);
+	e_action_group_add_actions_localized (
+		action_group, GETTEXT_PACKAGE,
+		mmp_entries, G_N_ELEMENTS (mmp_entries), shell_view);
 
 	g_signal_connect (shell_view, "update-actions", G_CALLBACK (update_mmp_entries_cb), NULL);
 
@@ -467,9 +472,9 @@ gw_ui_calendar_event_popup (GtkUIManager *ui_manager,
 	shell_window = e_shell_view_get_shell_window (shell_view);
 	action_group = e_shell_window_get_action_group (shell_window, "calendar");
 
-	gtk_action_group_add_actions (
-		action_group, cal_entries,
-		G_N_ELEMENTS (cal_entries), shell_view);
+	e_action_group_add_actions_localized (
+		action_group, GETTEXT_PACKAGE,
+		cal_entries, G_N_ELEMENTS (cal_entries), shell_view);
 
 	g_signal_connect (shell_view, "update-actions", G_CALLBACK (update_cal_entries_cb), NULL);
 
