@@ -27,7 +27,7 @@
 #include <string.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gconf/gconf-client.h>
 #include <e-util/e-config.h>
 #include <e-util/e-account-utils.h>
