@@ -26,7 +26,7 @@
 #endif
 
 #include <stdlib.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <libedataserverui/e-contact-store.h>
 
