@@ -25,7 +25,7 @@
 #endif
 
 #include <string.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include "camel-groupwise-settings.h"
 #include "mail/em-account-editor.h"
