@@ -24,10 +24,11 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+
 #include <string.h>
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <e-util/e-config.h>
 #include <e-util/e-account-utils.h>
 #include <mail/e-mail-backend.h>
